%% SIO227A Homework 5: 6.6 (Eric Gallimore)
% Ch 6 #6

%% Set up model
% load PREM model... we use selected values later
load('prem.txt');
depth_prem_all = prem(1:end-1,1);
vp_prem_all = prem(1:end-1,3);
%r_prem = prem(1:end-1,2);
% We just estimate Qalpha from figure 6.15.
%Qu_prem = prem(1:end-1, 6);
% We are staying out of the core, so Qk is infinite
%Qk_prem = prem(1:end-1, 7);


% We want attenuation for PcP ray paths.  That means that we will go from
% the surface (the bottom of the ocean at 3km) to the CMB and back.
% The core-mantle boundary is at depth 2891 km in the PREM model.
% Break it into layers using figure 6.15.
% We could do this more intelligently, but this works for both models
layer_bounds = [3,80,220,670,2891]; %km
layer_thickness = diff(layer_bounds); %km
Qa_prem = 1./[0.0007 0.0051 0.0028 0.0012];

% Get the average velocity in each of our new layers
for i = 1:(length(layer_bounds)-1)
    idx = find(depth_prem_all >= layer_bounds(i) & depth_prem_all <= layer_bounds(i+1));
    vp_prem(i) = mean(vp_prem_all(idx));
end

%% Find t*
% Remember that we have a two-way travel time.
% First, find t for each layer, given the velocity and depth of each layer.
t_layer = layer_thickness ./ vp_prem; % seconds
t_star_a = 2*sum(t_layer./Qa_prem); % seconds

fprintf('t* for PcP: %.4f s\n', t_star_a);

%% Find the attenuated amplitude
% We assume an initial amplitude (A_0) of 1, and a period of 30s.
period = 30; %s
f = 1/period; %Hz
omega = 2*pi*f; %rad/s

A_PcP = exp((-omega*t_star_a)/2);
fprintf('Relative amplitude for PcP (0.33Hz): %.4f \n', A_PcP);

%% Find the attenuated amplitude of ScS
% using the approximation tstar_beta = 4tstar_alpha
t_star_b = 4*t_star_a;
A_ScS = exp((-omega*t_star_b)/2);

fprintf('t* for ScS: %.4f s\n', t_star_b);
fprintf('Relative amplitude for ScS (0.33Hz): %f \n', A_ScS);

%% Repeat for 1Hz.
f = 1; %Hz
omega = 2*pi*f; %rad/s

A_PcP_1Hz = exp((-omega*t_star_a)/2);
A_ScS_1Hz = exp((-omega*t_star_b)/2);
fprintf('Relative amplitude for PcP (1Hz): %.4f \n', A_PcP_1Hz);
fprintf('Relative amplitude for ScS (1Hz): %f \n', A_ScS_1Hz);


%% Repeat for 1Hz using Warren and Shearer Qa values
% These values vary by frequency.  Forunately, the discontinuities are a
% subset of the values used for the PREM model.  So, we can easily build a
% vector that allows us to use the same methods used above.
% We still use the PREM values for velocity.
Qa_warren = 1./[0.0044 0.0044 0.0007 0.0007];

t_star_a_warren = 2*sum(t_layer./Qa_warren); % seconds
t_star_b_warren = 4*t_star_a_warren;

A_PcP_1Hz_warren = exp((-omega*t_star_a_warren)/2);
A_ScS_1Hz_warren = exp((-omega*t_star_b_warren)/2);

disp('Using Warren and Shearer:');
fprintf('t* for PcP: %.4f s\n', t_star_a_warren);
fprintf('t* for ScS: %.4f s\n', t_star_b_warren);
fprintf('Relative amplitude for PcP (1Hz): %.4f \n', A_PcP_1Hz_warren);
fprintf('Relative amplitude for ScS (1Hz): %f \n', A_ScS_1Hz_warren);




