%% Chapter 8 #4
%% Eric Gallimore

function ch8_4()

close all;

T = 50:500; % seconds
% Phase velocity
c = 4.020 - 1.839E-3*T + 3.071E-5*T.^2 - 3.549E-8*T.^3; % km/s


omega = 2*pi./T; % rad/s
%lambda = (2*pi*c)./omega; %km
%lambda = T.*c; %km (same as line above)
k = omega./c; % rad / km

% Group velocity
U = diff(omega)./diff(k); %km/s
% Duplicate the last element so that the vector is the same size as
% everything else
U(end+1) = U(end);

% Make a plot of the dispersion relation
figure('name', 'Dispersion curves for Raleigh Waves');
plot(T, c);
hold on;
plot(T, U, 'r--');
xlabel('Period (s)');
ylabel('Velocity (km/s)');
legend('Phase velocity', 'Group velocity', 'Location', 'NorthWest');

synthetic(0.0002, 'full');
synthetic(0.00002, 'full');
synthetic(0.00002, 'half');
synthetic(0.00002, 'none');

end

function synthetic(df, window_type)

dt = 5; % seconds
stop_time = 1.5*60*60; % seconds


ranges_degs = [0 30 90 150];
ranges = degrees_to_km(ranges_degs);

f = 0.002:df:0.02; %Hz
t = 0:dt:stop_time;


for i = 1:length(ranges)
   
    T = 1./f; % periods, seconds
    c = raleigh_phase_speed(T); %km/s
    
    t_offset = ranges(i) ./ c; % phase shift due to travel, s
    
    omega = 2*pi.*f; % rad/s
    
    % turn the time offsets into radial phase shifts
    % negative moves to the right.
    phi = -omega.*t_offset;

    % Get a series of sinusoids, one at each frequency (omega)
    sinusoids = cos(bsxfun(@plus, omega' * t, phi'));
    
    % Window to de-emphasize edge frequencies and reduce ringing
    if strcmp(window_type, 'full')
        window = hamming(length(omega));
    elseif strcmp(window_type, 'half')
        window = hamming(length(omega));
        % only window high frequencies
        window(1:floor(length(window)/2)) = 1;
    else
        window = ones(length(omega), 1);
    end
    windowed_sinusoids = bsxfun(@times, sinusoids, window);
    
    % Now, add the sinusoids.
    y(i, :) = sum(windowed_sinusoids);
end

% plot them
figure('name', ['Synthetic seismograms, df=' num2str(df) ' window: ' window_type]);
for i = 1:length(ranges)
    subplot(4,1,i);
    plot(t, y(i,:));
    xlabel('Time (s)');
    ylabel('Amplitude');
    title(['Range: ' num2str(ranges_degs(i)) ' degrees']);
end
suptitle(get(gcf(), 'name'));


% We can see that two peaks in the 150deg plot are about 100 seconds apart.
% At this period, the group velocity should be about 3.806 km/s
% The wave packet traveled about 16650 km in about 4350 seconds.
% That's a speed of 3.82 km/s, which is very close to the group velocity we
% calculated.



end

function c = raleigh_phase_speed(period)
    T = period; % seconds
    c = 4.020 - 1.839E-3*T + 3.071E-5*T.^2 - 3.549E-8*T.^3; % km/s
end

function km = degrees_to_km(degrees)
    km = 111.19 * degrees;
end
