clear all;
% distances in km, velocities in km/s

L = 100; %km
beta = 4; %km/s

dx = 1; %km
dt = 0.1; %s

t = 0:dt:33; %s
x = 0:dx:L; %km

u_source = sin(pi*t/5).^2; % displacement, km
source_duration = 5; %s

% pre-allocate u
% this also sets the initial conditions at t=0, t=dx to 0 for all x
u = zeros(length(x), length(t));

% Initialize u(t=0,x) to 0.
%u(:, 1) = zeros(length(x));
%u(:, 2) = zeros(length(x));

for it = 3:length(t)
    % Partial t
    for ix = 2:(length(x)-1)
        u(ix, it) = (beta^2 * (dt/dx)^2) * (u(ix-1, it-1) - 2*u(ix, it-1) + u(ix+1, it-1)) ...
            - u(ix, it-2) + 2*u(ix, it-1);
    end
    
    % Boundary conditions
    u(end, it) = 0;  % fixed boundary at x = L
    u(1, it) = u(2, it); % free boundary at x = 0
    % Forcing
    if t(it) < 5 % only first 5 seconds
        u(50, it) = u_source(it);
    end
    
    
end

close all;
% make a pretty plot
figure()
subplot_num = 1;
for i = 1:length(t);
    if mod(t(i) - 1, 4) == 0
        subplot(5,2,subplot_num);
        subplot_num = subplot_num + 1;
        plot(x, u(:, i));
        ylim([-1.1 1.1]);
        ylabel('Amplitude');
        xlabel('Horizontal distance x (km)');
        title_str = sprintf('Wave at t = %d s', t(i));
        title(title_str);
        pause(0.1);
        frames(i) = getframe;
    end
end


figure();
movie(frames);