close all;
clear;

load('prem.txt');

depth_prem = prem(1:end-1,1);
vp_prem = prem(1:end-1,3);
r_prem = prem(1:end-1,2);

a = 6371; %km

zf = -a * log(r_prem ./ a);

vp_f = (a./r_prem).*vp_prem;

plot(vp_f, -zf, 'g');
hold on;
plot(vp_prem, -depth_prem);
xlim([0 70])

% build the layer model
delta_zf = zf(1:end-1) - zf(2:end);
u_top = 1./vp_f(1:end-1);
u_bottom = 1./vp_f(2:end);


% OK, now trace some rays....
p = linspace(0.0017, 0.1128, 201); % ray parameter or horiz slowness, s/km
for ip = 1:length(p)
    % walk through the layers, starting at the top
    x = 0;
    t = 0;
    layer = 1;
    done = 0;
    
    for layer = 1:length(delta_zf)
        [dx, dt, irtr] = layerxt(p(ip), -delta_zf(layer), u_top(layer), u_bottom(layer));
        x = x+dx;
        t = t+dt;
        
        if irtr == 2
             % this is the end condition.
             break;
        end
    end
    xx(ip) = 2*x;
    tt(ip) = 2*t;
     
end


% now plot T(X)
figure()
plot(km_to_degrees(xx), tt./60, '.');
xlabel('Distance (degrees)');
ylabel('Time (minutes)');
xlim([0 180]);
ylim([0 25]);

t_with_reduction = tt - (km_to_degrees(xx)./0.1);
figure();
plot(km_to_degrees(xx), t_with_reduction, '.');
xlabel('Distance (degrees)');
ylabel('Time, reduced by 0.1m/s (seconds)');
xlim([10 35]);
ylim([50 100]);


