function plot_nice_spectrogram(signal, window, fs, max_dynamic_range, units_name)
    % the p argument in spectrogram is generated by pwelch with 'psd' set
    % as the spectrum type.  This preserves variance (area under this curve
    % is variance of signal)
    % The options are 
    %   'power' - compensate for Mean-square (Power) Spectrum;
    %             maintain the correct power peak heights.
    %   'psd'   - compensate for Power Spectral Density (PSD);
    %             maintain correct area under the PSD curve.
    % p is for positive frequencies only (so it's also scaled by 2)
    signal_nomean = signal - (mean(signal));
    
    % increase overlap
    %noverlap = floor(0.75*window);
    [s, f, t, p] = spectrogram(signal_nomean, window, [], window, fs);
    
    mag = 10*log10(abs(p));
    
    colormap(morgenstemning());
    surf(t, f, mag, 'EdgeColor', 'None');
    view([0 90]);
    xlabel('Time (s)');
    ylabel('Frequency (Hz)');
    cbar = colorbar();
    caxis([(max(max(mag))-max_dynamic_range) max(max(mag))]);
    bar_label = sprintf('Spectral density (dB re %s / Hz)', units_name);
    ylabel(cbar, bar_label);
    axis tight;
    
end